@@ -12,10 +12,10 @@ class CMakeProject(object):
 
     def __init__(self, name: str):
         self.name = name
-        self.parentProject: Optional[CMakeProject] = None
-        self.childProjects: List[CMakeProject] = []
-        self.directories: List[CMakeDirectory] = []
-        self.targets: List[CMakeTarget] = []
+        self.parentProject = None  # type: Optional[CMakeProject]
+        self.childProjects = []  # type: List[CMakeProject]
+        self.directories = []  # type: List[CMakeDirectory]
+        self.targets = []  # type:List[CMakeTarget]
 
     @classmethod
     def from_dict(cls, dikt: Dict) -> "CMakeProject":
@@ -46,10 +46,10 @@ class CMakeDirectory(object):
     def __init__(self, source: Path, build: Path, minimumCMakeVersion: Optional[str], hasInstallRule: bool):
         self.source = source
         self.build = build
-        self.parentDirectory: Optional[CMakeDirectory] = None
-        self.childDirectories: List[CMakeDirectory] = []
-        self.project: CMakeProject = None
-        self.targets: List[CMakeTarget] = []
+        self.parentDirectory = None  # type: Optional[CMakeDirectory]
+        self.childDirectories = []  # type: List[CMakeDirectory]
+        self.project = None  # type: Optional[CMakeProject]
+        self.targets = []  # type: List[CMakeTarget]
         self.minimumCMakeVersion = minimumCMakeVersion
         self.hasInstallRule = hasInstallRule
 
@@ -101,7 +101,7 @@ class CMakeTarget(object):
         name = dikt["name"]
         directory = directories[dikt["directoryIndex"]]
         project = projects[dikt["projectIndex"]]
-        jsonFile = reply_path / Path(dikt["jsonFile"])
+        jsonFile = reply_path / dikt["jsonFile"]
         target = CodemodelTargetV2.from_path(jsonFile, reply_path)
         return cls(name, directory, project, jsonFile, target)
 
@@ -188,5 +188,5 @@ class CodemodelV2(object):
             type(self).__name__,
             self.version,
             self.paths,
-            list(configuration.name for configuration in self.configurations),
+            self.configurations,
         )
